using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Microsoft.SharePoint;

namespace DocLibBrowser
{
    public partial class Form1 : Form
    {
        SPWeb sourceWeb;
        SPDocumentLibrary selectedLib;

        public Form1()
        {
            InitializeComponent();
        }

        private void exploreButton_Click(object sender, EventArgs e)
        {
            SPSite sourceSite = new SPSite(siteUrl.Text);
            sourceWeb = sourceSite.AllWebs[siteName.Text];

            DocLibPicker picker = new DocLibPicker(sourceWeb);
            if (picker.ShowDialog() == DialogResult.OK)
            {
                selectedLib = picker.SelectedLibrary;
                folderTree.Nodes.Add(selectedLib.Title);
                foreach (SPListItem folderItem in selectedLib.Folders)
                {
                    System.Diagnostics.Debug.WriteLine("Top-level folder found : " +
                        folderItem.Name);
                    if (folderItem.Folder.ParentFolder.Name.ToUpper() ==
                        selectedLib.Title.ToUpper()) // weed out non-top-level nodes
                        PopulateTree(folderItem, folderTree.Nodes[0]);
                }
                
            }
        }

        private void PopulateTree(SPListItem folderItem, TreeNode rootNode)
        {
            SPFolder realFolder = folderItem.Folder;
            TreeNode newNode = new TreeNode(folderItem.Name);
            newNode.Tag = realFolder;
            rootNode.Nodes.Add(newNode);
            foreach (SPFolder subFolder in realFolder.SubFolders)
            {
                PopulateTree(subFolder.Item, newNode);
            }            
        }

        private void folderTree_AfterSelect(object sender, TreeViewEventArgs e)
        {
            documentList.Items.Clear();
            if (e.Node.Level > 0) // not root node
            {
                SPFolder folder = (SPFolder)e.Node.Tag;
                System.Diagnostics.Debug.WriteLine("Folder clicked " + folder.Name);
                foreach (SPFile file in folder.Files)
                {           
                    ListViewItem lvi = new ListViewItem(file.Name);                    
                    lvi.SubItems.Add(file.MajorVersion.ToString() + "." + file.MinorVersion.ToString());
                    lvi.SubItems.Add(file.Author.Name);
                    documentList.Items.Add(lvi);
                }
            }
        }
    }
}