using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Office.Server;
using Microsoft.Office.Server.Administration;
using Microsoft.Office.Server.UserProfiles;
using Microsoft.SharePoint;
using System.Web;

namespace UserProfilesOMApp
{
    class Program
    {
        static void Main(string[] args)
        {

            using (SPSite site = new SPSite("http://win2k3r2lab"))
            {
                ServerContext context = ServerContext.GetContext(site);
                UserProfileManager profileManager =
                    new UserProfileManager(context);

                // Get all changes to profile made in the last 5 days
                DateTime startDate =
                    DateTime.UtcNow.Subtract(TimeSpan.FromDays(5));
                UserProfileChangeQuery changeQuery =
                    new UserProfileChangeQuery(false, true);
                UserProfileChangeToken changeToken =
                    new UserProfileChangeToken(startDate);
                changeQuery.ChangeTokenStart = changeToken;
                changeQuery.Anniversary = true;
                changeQuery.SingleValueProperty = true;
                changeQuery.MultiValueProperty = true;
                changeQuery.DistributionListMembership = true;
                changeQuery.SiteMembership = true;

                UserProfile bobProfile = profileManager.GetUserProfile(
                    @"win2k3r2lab\bjohnson");

                UserProfileChangeCollection changes =
                    bobProfile.GetChanges(changeQuery);

                foreach (UserProfileChange change in changes)
                {
                    Console.WriteLine(change.EventTime.ToString());
                    if (change is UserProfilePropertyValueChange)
                    {
                        UserProfilePropertyValueChange propertyChange =
                            (UserProfilePropertyValueChange)change;
                        Console.WriteLine("Property {0} - {1}", propertyChange.ProfileProperty.Name,
                            propertyChange.ChangeType.ToString());                        
                    }
                    else if (change is UserProfileMembershipChange)
                    {
                        UserProfileMembershipChange membershipChange =
                            (UserProfileMembershipChange)change;
                        Console.WriteLine("Membership {0} - {1}", membershipChange.MemberGroup.DisplayName,
                            membershipChange.ChangeType.ToString());
                    }

                }
                Console.ReadLine();
            }
        }
    }
}
