using System;
using System.IO;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Xml;
using System.Windows.Forms;

namespace PhotoBrowser
{
    public partial class Form1 : Form
    {
        private win2k3r2lab.Imaging imageService = null;
        private DataSet imageSet = null;
        private PictureBox lastPictureClicked = null;        

        public Form1()
        {
            InitializeComponent();
            imageService = new PhotoBrowser.win2k3r2lab.Imaging();
            imageService.Url = "http://win2k3r2lab/picturedemo/_vti_bin/imaging.asmx";
            // this only works if your windows ID is acceptable to the site!
            imageService.Credentials = System.Net.CredentialCache.DefaultCredentials;
            imageService.DownloadCompleted += 
                new PhotoBrowser.win2k3r2lab.DownloadCompletedEventHandler(imageService_DownloadCompleted);

            XmlNode pictureNode = imageService.ListPictureLibrary();
            foreach (XmlNode library in pictureNode.ChildNodes)
            {
                ListViewItem lvi = new ListViewItem();
                lvi.Text = library.Attributes.GetNamedItem("title").Value;
                lvi.Tag = library.Attributes.GetNamedItem("url").Value;
                libraryList.Items.Add(lvi);
            }
        }

        void imageService_DownloadCompleted(object sender, PhotoBrowser.win2k3r2lab.DownloadCompletedEventArgs e)
        {
            XmlNode fileDownload = e.Result;
            int idx = (int)e.UserState;
            //System.Diagnostics.Debug.WriteLine(fileDownload.InnerXml);
            string fileByteString = fileDownload.InnerText;
            byte[] fileBytes = Convert.FromBase64String(fileByteString);
            ((PictureBox)imageFlow.Controls[idx]).Image = Image.FromStream(new System.IO.MemoryStream(fileBytes)); 
            //MessageBox.Show(idx.ToString());
            
        }

        private void libraryList_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (libraryList.SelectedItems.Count == 0) return;
            imageFlow.Controls.Clear();
            ListViewItem lvi = libraryList.SelectedItems[0];
            string url = (string)lvi.Tag;

            XmlNode listItemsNode = imageService.GetListItems(url, "");
            imageSet = new DataSet();
            string sourceXml = "<images>" + listItemsNode.InnerXml + "</images>";
            imageSet.ReadXml(new System.IO.StringReader(sourceXml));
            int x = 0;
            foreach (DataRow row in imageSet.Tables[0].Rows)
            {
                PictureBox picture = new PictureBox();
                picture.SizeMode = PictureBoxSizeMode.StretchImage;
                picture.Height = 160;
                picture.Width = 140;                
                picture.Click += new EventHandler(picture_Click);
                picture.Tag = row;
                pictureToolTip.SetToolTip(picture, row["ows_Title"] == DBNull.Value ? "(untitled)" : (string)row["ows_Title"]);
                picture.BorderStyle = BorderStyle.None;
                string fileRef = (string)row["ows_FileRef"];
                string[] fileRefs = fileRef.Split(';');
                string fileName = fileRefs[1].Substring(1, fileRefs[1].Length - 1); // remove leading #
                fileName = System.IO.Path.GetFileName(fileName);
                // type: 0, original, 1 thumbnail, 2 web image
                System.Diagnostics.Debug.WriteLine("Attempting to download " + fileName + " from list " + url);
                imageService.DownloadAsync(url, "", new string[] { fileName }, 1, false, x);
                imageFlow.Controls.Add(picture);
                x++;
            }
            //MessageBox.Show(listItemsNode.InnerXml);
        }        

        void picture_Click(object sender, EventArgs e)
        {
            if (lastPictureClicked != null)
                lastPictureClicked.BorderStyle = BorderStyle.None;            

            lastPictureClicked = (PictureBox)sender;
            lastPictureClicked.BorderStyle = BorderStyle.Fixed3D;
        }

        private void deleteButton_Click(object sender, EventArgs e)
        {
            string fileName;
            if (lastPictureClicked != null)
            {
                string url = GetListUrl();
                fileName = GetFileName();

                imageService.Delete(url, "", new string[] { fileName });
                imageFlow.Controls.Remove(lastPictureClicked);
                lastPictureClicked = null;                                
            }
        }

        private string GetListUrl()
        {
            ListViewItem listItem = libraryList.SelectedItems[0];
            return (string)listItem.Tag;
        }

        private string GetFileName()
        {
            DataRow row = (DataRow)lastPictureClicked.Tag;
            ListViewItem listItem = libraryList.SelectedItems[0];
            string url = (string)listItem.Tag;
            string fileRef = (string)row["ows_FileRef"];
            string[] fileRefs = fileRef.Split(';');
            string fileName = fileRefs[1].Substring(1, fileRefs[1].Length - 1);
            fileName = System.IO.Path.GetFileName(fileName);

            return fileName;
        }

        private void renameButton_Click(object sender, EventArgs e)
        {
            using (RenameForm rename = new RenameForm())
            {
                rename.ShowDialog();
                string newName = rename.NewName;
                ListViewItem listItem = libraryList.SelectedItems[0];
                string list = (string)listItem.Tag;
                XmlDocument doc = new XmlDocument();
                string fileName = GetFileName();
                doc.InnerXml = string.Format(
                    "<Request><files><file filename=\"{0}\" newbasename=\"{1}\" /></files></Request>",
                    fileName, newName);
                XmlElement requestElement = doc.DocumentElement;

                imageService.Rename(list, "", requestElement);
            }
        }

        private void viewButton_Click(object sender, EventArgs e)
        {
            DataRow row = (DataRow)lastPictureClicked.Tag;
            string url = GetListUrl();
            string fileName = GetFileName();
            XmlNode imageNode = imageService.Download(url, "", new string[] { fileName }, 0, false);
            string fileByteString = imageNode.InnerText;
            byte[] fileBytes = Convert.FromBase64String(fileByteString);
            using (PhotoDetail detail = new PhotoDetail(row, fileBytes))
            {
                detail.ShowDialog();
            }
        }

        private void uploadButton_Click(object sender, EventArgs e)
        {
            if (uploadDialog.ShowDialog() == DialogResult.OK)
            {
                string fileName = uploadDialog.FileName;        
                FileStream fs = new FileStream(fileName, FileMode.Open);
                byte[] fileBytes = new byte[fs.Length];
                fs.Read(fileBytes, 0, (int)fs.Length);
                string url = GetListUrl();
                imageService.Upload(url, "", fileBytes, Path.GetFileName(fileName), true);
                MessageBox.Show("Image Uploaded.");
            }
        }

        private void metaButton_Click(object sender, EventArgs e)
        {
            string url = GetListUrl();
            string fileName = GetFileName();

            XmlNode metaNode = imageService.GetItemsXMLData(url, "", new string[] { fileName });
            MessageBox.Show(metaNode.InnerXml);
        }

        private void getByIdButton_Click(object sender, EventArgs e)
        {
            string url = GetListUrl();
            DataRow row = (DataRow)lastPictureClicked.Tag;
            string id = (string)row["ows_ID"];
            uint itemId = uint.Parse(id);

            XmlNode itemsNode = imageService.GetItemsByIds(url, new uint[] { itemId });
            MessageBox.Show(itemsNode.InnerXml);
        }        
        
    }
}