using System;
using System.ComponentModel;
using System.Xml;
using System.Xml.Serialization;
using System.Collections.Generic;
using System.Text;

namespace SAMS.SharePoint.Tools.ListLibrary
{
    public class StandardListItem : INotifyPropertyChanged
    {
        protected int _id = 0;
        protected int _attachments = 0;
        protected int _hiddenVersion = 0;
        protected string _linkTitle = string.Empty;
        protected string _title = string.Empty;
        protected BatchMode _batchMode;        

        public StandardListItem() 
        {
            _batchMode = BatchMode.None;
        }        

        [XmlAttribute("ows_Title")]
        [SharePointListField("ows_Title")]
        public string Title
        {
            get
            {
                return _title;
            }
            set
            {
                _title = value;
                NotifyPropertyChanged("Title");
            }
        }

        [XmlAttribute("ows_Attachments")]        
        public int AttachmentCount
        {
            get
            {
                return _attachments;
            }
            set
            {
                _attachments = value;
            }
        }

        [XmlAttribute("ows_hiddenversion")]
        public int HiddenVersion
        {
            get
            {
                return _hiddenVersion;
            }
            set
            {
                _hiddenVersion = value;
            }
        }

        [XmlAttribute("ows_ID")]
        [SharePointListField("ows_ID")]
        public int ID
        {
            get
            {
                return _id;
            }
            set
            {
                _id = value;
            }
        }

        [XmlAttribute("ows_LinkTitle")]
        public string LinkTitle
        {
            get
            {
                return _linkTitle;
            }
            set
            {
                _linkTitle = value;
                NotifyPropertyChanged("LinkTitle");
            }
        }

        protected void NotifyPropertyChanged(string property)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(property));            
        }

        public BatchMode BatchMode
        {
            get { return _batchMode; }
            set { _batchMode = value; }
        }


        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion
    }
}
